@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.2.0",
-        meson_version="1.2.3",
+        contourpy_version="1.2.1",
+        meson_version="1.4.0",
         mesonpy_version="0.15.0",
-        pybind11_version="2.11.1",
+        pybind11_version="2.12.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.2.0/.mesonpy-v18clu5m/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy-1.2.0/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-c7vg05eb/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy-1.2.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.0/.mesonpy-v18clu5m/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-c7vg05eb/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
